@@ -6,12 +6,12 @@
 	it under the terms of the GNU Library General Public License as
 	published by the Free Software Foundation; either version 2 of
 	the License, or (at your option) any later version.
- 
+
 	This program is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU Library General Public License for more details.
- 
+
 	You should have received a copy of the GNU Library General Public
 	License along with this library; if not, write to the Free Software
 	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -44,9 +44,12 @@
 #include <string.h>
 
 #define INITGUID
+#if !defined(__cplusplus) && !defined(CINTERFACE)
+#define CINTERFACE
+#endif
 #include <dsound.h>
 
-/* Not in compilers <= MSVC 6 */
+/* PF_XMMI64_INSTRUCTIONS_AVAILABLE not in all SDKs */
 #ifndef PF_XMMI64_INSTRUCTIONS_AVAILABLE
 #define PF_XMMI64_INSTRUCTIONS_AVAILABLE 10
 #endif
@@ -59,6 +62,10 @@
 						  DSBCAPS_CTRL3D )
 #endif
 
+#ifndef WAVE_FORMAT_IEEE_FLOAT
+#define WAVE_FORMAT_IEEE_FLOAT 0x0003
+#endif
+
 /* size of each buffer */
 #define FRAGSIZE 16
 /* buffer count */
@@ -68,21 +75,11 @@ static LPDIRECTSOUND pSoundCard = NULL;
 static LPDIRECTSOUNDBUFFER pPrimarySoundBuffer = NULL, pSoundBuffer = NULL;
 static LPDIRECTSOUNDNOTIFY pSoundBufferNotify = NULL;
 
-static HANDLE notifyUpdateHandle = 0, updateBufferHandle = 0;
+static HANDLE notifyUpdateHandle = NULL, updateBufferHandle = NULL;
 static BOOL threadInUse = FALSE;
 static int fragsize=1<<FRAGSIZE;
 static DWORD controlflags = DSBCAPS_CTRLALL & ~DSBCAPS_GLOBALFOCUS;
 
-#define SAFE_RELEASE(p) \
-	do { \
-		if (p) { \
-			if ((p)->lpVtbl) { \
-				(p)->lpVtbl->Release(p); \
-				(p) = NULL;	\
-			} \
-		} \
-	} while (0)
-
 static DWORD WINAPI updateBufferProc(LPVOID lpParameter)
 {
 	LPVOID pBlock1 = NULL, pBlock2 = NULL;
@@ -94,7 +91,7 @@ static DWORD WINAPI updateBufferProc(LPVOID lpParameter)
 
 			if (!threadInUse) break;
 
-			pSoundBuffer->lpVtbl->GetCurrentPosition
+			IDirectSoundBuffer_GetCurrentPosition
 						(pSoundBuffer,&soundBufferCurrentPosition,NULL);
 
 			if (soundBufferCurrentPosition < fragsize)
@@ -102,11 +99,11 @@ static DWORD WINAPI updateBufferProc(LPVOID lpParameter)
 			else
 				start = 0;
 
-			if (pSoundBuffer->lpVtbl->Lock
+			if (IDirectSoundBuffer_Lock
 						(pSoundBuffer,start,fragsize,&pBlock1,&blockBytes1,
-						 &pBlock2,&blockBytes2,0)==DSERR_BUFFERLOST) {	
-				pSoundBuffer->lpVtbl->Restore(pSoundBuffer);
-				pSoundBuffer->lpVtbl->Lock
+						 &pBlock2,&blockBytes2,0)==DSERR_BUFFERLOST) {
+				IDirectSoundBuffer_Restore(pSoundBuffer);
+				IDirectSoundBuffer_Lock
 						(pSoundBuffer,start,fragsize,&pBlock1,&blockBytes1,
 						 &pBlock2,&blockBytes2,0);
 			}
@@ -122,15 +119,15 @@ static DWORD WINAPI updateBufferProc(LPVOID lpParameter)
 					VC_WriteBytes((SBYTE*)pBlock2,(ULONG)blockBytes2);
 			}
 			MUTEX_UNLOCK(vars);
-			
-			pSoundBuffer->lpVtbl->Unlock
+
+			IDirectSoundBuffer_Unlock
 						(pSoundBuffer,pBlock1,blockBytes1,pBlock2,blockBytes2);
 		}
 	}
 	return 0;
 }
 
-static void DS_CommandLine(CHAR *cmdline)
+static void DS_CommandLine(const CHAR *cmdline)
 {
 	CHAR *ptr=MD_GetAtom("buffer",cmdline,0);
 
@@ -142,8 +139,9 @@ static void DS_CommandLine(CHAR *cmdline)
 
 		MikMod_free(ptr);
 	}
-	
-	if ((ptr=MD_GetAtom("globalfocus",cmdline,1))) {
+
+	ptr=MD_GetAtom("globalfocus",cmdline,1);
+	if (ptr) {
 		controlflags |= DSBCAPS_GLOBALFOCUS;
 		MikMod_free(ptr);
 	} else
@@ -154,73 +152,80 @@ static BOOL DS_IsPresent(void)
 {
 	if(DirectSoundCreate(NULL,&pSoundCard,NULL)!=DS_OK)
 		return 0;
-	SAFE_RELEASE(pSoundCard);
+	if (pSoundCard) {
+		IDirectSound_Release(pSoundCard);
+		pSoundCard = NULL;
+	}
 	return 1;
 }
 
-static BOOL DS_Init(void)
+static int DS_Init(void)
 {
 	DSBUFFERDESC soundBufferFormat;
 	WAVEFORMATEX pcmwf;
 	DSBPOSITIONNOTIFY positionNotifications[2];
 	DWORD updateBufferThreadID;
+	LPVOID p = NULL;
 
 	if (DirectSoundCreate(NULL,&pSoundCard,NULL)!=DS_OK) {
 		_mm_errno=MMERR_OPENING_AUDIO;
 		return 1;
 	}
 
-	if (pSoundCard->lpVtbl->SetCooperativeLevel
+	if (IDirectSound_SetCooperativeLevel
 				(pSoundCard,GetForegroundWindow(),DSSCL_PRIORITY)!=DS_OK) {
 		_mm_errno=MMERR_DS_PRIORITY;
 		return 1;
 	}
 
 	memset(&soundBufferFormat,0,sizeof(DSBUFFERDESC));
-    soundBufferFormat.dwSize       =sizeof(DSBUFFERDESC);
-    soundBufferFormat.dwFlags      =DSBCAPS_PRIMARYBUFFER;
-    soundBufferFormat.dwBufferBytes=0;
-    soundBufferFormat.lpwfxFormat  =NULL;
+	soundBufferFormat.dwSize = sizeof(DSBUFFERDESC);
+	soundBufferFormat.dwFlags = DSBCAPS_PRIMARYBUFFER;
+	soundBufferFormat.dwBufferBytes = 0;
+	soundBufferFormat.lpwfxFormat = NULL;
 
-	if (pSoundCard->lpVtbl->CreateSoundBuffer
+	if (IDirectSound_CreateSoundBuffer
 				(pSoundCard,&soundBufferFormat,&pPrimarySoundBuffer,NULL)!=DS_OK) {
 		_mm_errno=MMERR_DS_BUFFER;
 		return 1;
 	}
 
 	memset(&pcmwf,0,sizeof(WAVEFORMATEX));
-	pcmwf.wFormatTag     =WAVE_FORMAT_PCM;
+	pcmwf.wFormatTag     =(md_mode&DMODE_FLOAT)? WAVE_FORMAT_IEEE_FLOAT : WAVE_FORMAT_PCM;
 	pcmwf.nChannels      =(md_mode&DMODE_STEREO)?2:1;
 	pcmwf.nSamplesPerSec =md_mixfreq;
-	pcmwf.wBitsPerSample =(md_mode&DMODE_16BITS)?16:8;
+	pcmwf.wBitsPerSample =(md_mode&DMODE_FLOAT)?32:(md_mode&DMODE_16BITS)?16:8;
 	pcmwf.nBlockAlign    =(pcmwf.wBitsPerSample * pcmwf.nChannels) / 8;
 	pcmwf.nAvgBytesPerSec=pcmwf.nSamplesPerSec*pcmwf.nBlockAlign;
 
-    if (pPrimarySoundBuffer->lpVtbl->SetFormat
-				(pPrimarySoundBuffer,&pcmwf)!=DS_OK) {
+	if (IDirectSoundBuffer_SetFormat(pPrimarySoundBuffer,&pcmwf)!=DS_OK) {
 		_mm_errno=MMERR_DS_FORMAT;
 		return 1;
 	}
-    pPrimarySoundBuffer->lpVtbl->Play(pPrimarySoundBuffer,0,0,DSBPLAY_LOOPING);
+	IDirectSoundBuffer_Play(pPrimarySoundBuffer,0,0,DSBPLAY_LOOPING);
 
 	memset(&soundBufferFormat,0,sizeof(DSBUFFERDESC));
-    soundBufferFormat.dwSize       =sizeof(DSBUFFERDESC);
-    soundBufferFormat.dwFlags      =controlflags|DSBCAPS_GETCURRENTPOSITION2 ;
-    soundBufferFormat.dwBufferBytes=fragsize*UPDATES;
-    soundBufferFormat.lpwfxFormat  =&pcmwf;
-	
-	if (pSoundCard->lpVtbl->CreateSoundBuffer
+	soundBufferFormat.dwSize	=sizeof(DSBUFFERDESC);
+	soundBufferFormat.dwFlags	=controlflags|DSBCAPS_GETCURRENTPOSITION2 ;
+	soundBufferFormat.dwBufferBytes =fragsize*UPDATES;
+	soundBufferFormat.lpwfxFormat	=&pcmwf;
+
+	if (IDirectSound_CreateSoundBuffer
 				(pSoundCard,&soundBufferFormat,&pSoundBuffer,NULL)!=DS_OK) {
 		_mm_errno=MMERR_DS_BUFFER;
 		return 1;
 	}
 
-	pSoundBuffer->lpVtbl->QueryInterface
-				(pSoundBuffer,&IID_IDirectSoundNotify,(LPVOID*)&pSoundBufferNotify);
-	if (!pSoundBufferNotify) {
+#ifdef __cplusplus
+	IDirectSoundBuffer_QueryInterface(pSoundBuffer, IID_IDirectSoundNotify,&p);
+#else
+	IDirectSoundBuffer_QueryInterface(pSoundBuffer,&IID_IDirectSoundNotify,&p);
+#endif
+	if (!p) {
 		_mm_errno=MMERR_DS_NOTIFY;
 		return 1;
 	}
+	pSoundBufferNotify = (LPDIRECTSOUNDNOTIFY) p;
 
 	notifyUpdateHandle=CreateEvent
 				(NULL,FALSE,FALSE,"libmikmod DirectSound Driver positionNotify Event");
@@ -241,16 +246,18 @@ static BOOL DS_Init(void)
 	positionNotifications[0].hEventNotify=notifyUpdateHandle;
 	positionNotifications[1].dwOffset    =fragsize;
 	positionNotifications[1].hEventNotify=notifyUpdateHandle;
-	if (pSoundBufferNotify->lpVtbl->SetNotificationPositions
+	if (IDirectSoundNotify_SetNotificationPositions
 				(pSoundBufferNotify,2,positionNotifications) != DS_OK) {
 		_mm_errno=MMERR_DS_UPDATE;
 		return 1;
 	}
 
-	if (IsProcessorFeaturePresent(PF_XMMI64_INSTRUCTIONS_AVAILABLE))
-	{
+#if defined HAVE_SSE2
+	/* this test only works on Windows XP or later */
+	if (IsProcessorFeaturePresent(PF_XMMI64_INSTRUCTIONS_AVAILABLE)) {
 		md_mode|=DMODE_SIMDMIXER;
 	}
+#endif
 	return VC_Init();
 }
 
@@ -259,7 +266,6 @@ static void DS_Exit(void)
 	DWORD statusInfo;
 
 	if(updateBufferHandle) {
-
 		/* Signal thread to exit and wait for the exit */
 		if (threadInUse) {
 			threadInUse = 0;
@@ -270,30 +276,37 @@ static void DS_Exit(void)
 		}
 
 		CloseHandle(updateBufferHandle),
-		updateBufferHandle = 0;
+		updateBufferHandle = NULL;
 	}
 	if (notifyUpdateHandle) {
 		CloseHandle(notifyUpdateHandle),
-		notifyUpdateHandle = 0;
+		notifyUpdateHandle = NULL;
 	}
 
-	SAFE_RELEASE(pSoundBufferNotify);
+	if (pSoundBufferNotify) {
+		IDirectSoundNotify_Release(pSoundBufferNotify);
+		pSoundBufferNotify = NULL;
+	}
 	if(pSoundBuffer) {
-		if(pSoundBuffer->lpVtbl->GetStatus(pSoundBuffer,&statusInfo)==DS_OK)
+		if(IDirectSoundBuffer_GetStatus(pSoundBuffer,&statusInfo)==DS_OK)
 			if(statusInfo&DSBSTATUS_PLAYING)
-				pSoundBuffer->lpVtbl->Stop(pSoundBuffer);
-		SAFE_RELEASE(pSoundBuffer);
+				IDirectSoundBuffer_Stop(pSoundBuffer);
+		IDirectSoundBuffer_Release(pSoundBuffer);
+		pSoundBuffer = NULL;
 	}
 
 	if(pPrimarySoundBuffer) {
-		if(pPrimarySoundBuffer->lpVtbl->GetStatus
-						(pPrimarySoundBuffer,&statusInfo)==DS_OK)
+		if(IDirectSoundBuffer_GetStatus(pPrimarySoundBuffer,&statusInfo)==DS_OK)
 			if(statusInfo&DSBSTATUS_PLAYING)
-				pPrimarySoundBuffer->lpVtbl->Stop(pPrimarySoundBuffer);
-		SAFE_RELEASE(pPrimarySoundBuffer);
+				IDirectSoundBuffer_Stop(pPrimarySoundBuffer);
+		IDirectSoundBuffer_Release(pPrimarySoundBuffer);
+		pPrimarySoundBuffer = NULL;
 	}
 
-	SAFE_RELEASE(pSoundCard);
+	if (pSoundCard) {
+		IDirectSound_Release(pSoundCard);
+		pSoundCard = NULL;
+	}
 
 	VC_Exit();
 }
@@ -310,12 +323,10 @@ static void DS_Update(void)
 	if (do_update && pSoundBuffer) {
 		do_update = 0;
 
-		if (pSoundBuffer->lpVtbl->Lock (pSoundBuffer, 0, fragsize,
-										&block, &bBytes, NULL, NULL, 0)
-				== DSERR_BUFFERLOST) {
-			pSoundBuffer->lpVtbl->Restore (pSoundBuffer);
-			pSoundBuffer->lpVtbl->Lock (pSoundBuffer, 0, fragsize,
-										&block, &bBytes, NULL, NULL, 0);
+		if (IDirectSoundBuffer_Lock(pSoundBuffer, 0, fragsize, &block, &bBytes, NULL, NULL, 0)
+											== DSERR_BUFFERLOST) {
+			IDirectSoundBuffer_Restore (pSoundBuffer);
+			IDirectSoundBuffer_Lock (pSoundBuffer, 0, fragsize, &block, &bBytes, NULL, NULL, 0);
 		}
 
 		if (Player_Paused_internal()) {
@@ -324,10 +335,10 @@ static void DS_Update(void)
 			VC_WriteBytes ((SBYTE *)block, (ULONG)bBytes);
 		}
 
-		pSoundBuffer->lpVtbl->Unlock (pSoundBuffer, block, bBytes, NULL, 0);
+		IDirectSoundBuffer_Unlock (pSoundBuffer, block, bBytes, NULL, 0);
 
-		pSoundBuffer->lpVtbl->SetCurrentPosition(pSoundBuffer, 0);
-		pSoundBuffer->lpVtbl->Play(pSoundBuffer, 0, 0, DSBPLAY_LOOPING);
+		IDirectSoundBuffer_SetCurrentPosition(pSoundBuffer, 0);
+		IDirectSoundBuffer_Play(pSoundBuffer, 0, 0, DSBPLAY_LOOPING);
 
 		threadInUse=1;
 		ResumeThread (updateBufferHandle);
@@ -338,11 +349,11 @@ static void DS_PlayStop(void)
 {
 	do_update = 0;
 	if (pSoundBuffer)
-		pSoundBuffer->lpVtbl->Stop(pSoundBuffer);
+		IDirectSoundBuffer_Stop(pSoundBuffer);
 	VC_PlayStop();
 }
 
-static BOOL DS_PlayStart(void)
+static int DS_PlayStart(void)
 {
 	do_update = 1;
 	return VC_PlayStart();
@@ -352,11 +363,11 @@ MIKMODAPI MDRIVER drv_ds=
 {
 	NULL,
 	"DirectSound",
-	"DirectSound Driver (DX6+) v0.4",
+	"DirectSound Driver (DX6+) v0.6",
 	0,255,
 	"ds",
 	"buffer:r:12,19,16:Audio buffer log2 size\n"
-        "globalfocus:b:0:Play if window does not have the focus\n",
+		"globalfocus:b:0:Play if window does not have the focus\n",
 	DS_CommandLine,
 	DS_IsPresent,
 	VC_SampleLoad,
