@@ -94,7 +94,8 @@ static int ESD_Link(void)
 	if (libesd) return 0;
 
 	/* load libesd.so */
-	libesd=dlopen("libesd.so",RTLD_LAZY|RTLD_GLOBAL);
+	libesd=dlopen("libesd.so.0",RTLD_LAZY|RTLD_GLOBAL);
+	if (!libesd) libesd=dlopen("libesd.so",RTLD_LAZY|RTLD_GLOBAL);
 	if (!libesd) return 1;
 
 	/* resolve function references */
@@ -206,7 +207,7 @@ static void ESD_CommandLine(const CHAR *cmdline)
 	CHAR *ptr=MD_GetAtom("machine",cmdline,0);
 
 	if (ptr) {
-		if (espeaker) MikMod_free(espeaker);
+		MikMod_free(espeaker);
 		espeaker=ptr;
 	}
 }
