@@ -21,8 +21,6 @@
 
 /*==============================================================================
 
-  $Id$
-
   WAV sample loader
 
 ==============================================================================*/
@@ -259,7 +257,6 @@ MIKMODAPI SAMPLE* Sample_LoadRawGeneric(MREADER* reader, ULONG rate, ULONG chann
 	SAMPLE* result;
 
 	MUTEX_LOCK(vars);
-/*	result = Sample_LoadRawGeneric_internal(reader, NULL);*/
 	result = Sample_LoadRawGeneric_internal(reader, rate, channel, flags);
 	MUTEX_UNLOCK(vars);
 
@@ -271,7 +268,8 @@ MIKMODAPI extern SAMPLE *Sample_LoadRawMem(const char *buf, int len, ULONG rate,
 	SAMPLE *result=NULL;
 	MREADER *reader;
 
-	if ((reader=_mm_new_mem_reader(buf, len))) {
+	if (!buf || len <= 0) return NULL;
+	if ((reader=_mm_new_mem_reader(buf, len)) != NULL) {
 		result=Sample_LoadRawGeneric(reader, rate, channel, flags);
 		_mm_delete_mem_reader(reader);
 	}
@@ -283,7 +281,7 @@ MIKMODAPI SAMPLE* Sample_LoadRawFP(FILE *fp, ULONG rate, ULONG channel, ULONG fl
 	SAMPLE* result=NULL;
 	MREADER* reader;
 
-	if((reader=_mm_new_file_reader(fp))) {
+	if(fp && (reader=_mm_new_file_reader(fp)) != NULL) {
 		result=Sample_LoadRawGeneric(reader, rate, channel, flags);
 		_mm_delete_file_reader(reader);
 	}
@@ -295,10 +293,8 @@ MIKMODAPI SAMPLE* Sample_LoadRaw(const CHAR* filename, ULONG rate, ULONG channel
 	FILE *fp;
 	SAMPLE *si=NULL;
 
-	printf("filename: %s\n", filename);
-
 	if(!(md_mode & DMODE_SOFT_SNDFX)) return NULL;
-	if((fp=_mm_fopen(filename,"rb"))) {
+	if((fp=_mm_fopen(filename,"rb")) != NULL) {
 		si = Sample_LoadRawFP(fp, rate, channel, flags);
 		_mm_fclose(fp);
 	}
@@ -321,7 +317,8 @@ MIKMODAPI extern SAMPLE *Sample_LoadMem(const char *buf, int len)
 	SAMPLE* result=NULL;
 	MREADER* reader;
 
-	if ((reader=_mm_new_mem_reader(buf, len))) {
+	if (!buf || len <= 0) return NULL;
+	if ((reader=_mm_new_mem_reader(buf, len)) != NULL) {
 		result=Sample_LoadGeneric(reader);
 		_mm_delete_mem_reader(reader);
 	}
@@ -333,7 +330,7 @@ MIKMODAPI SAMPLE* Sample_LoadFP(FILE *fp)
 	SAMPLE* result=NULL;
 	MREADER* reader;
 
-	if((reader=_mm_new_file_reader(fp))) {
+	if(fp && (reader=_mm_new_file_reader(fp)) != NULL) {
 		result=Sample_LoadGeneric(reader);
 		_mm_delete_file_reader(reader);
 	}
@@ -346,7 +343,7 @@ MIKMODAPI SAMPLE* Sample_Load(const CHAR* filename)
 	SAMPLE *si=NULL;
 
 	if(!(md_mode & DMODE_SOFT_SNDFX)) return NULL;
-	if((fp=_mm_fopen(filename,"rb"))) {
+	if((fp=_mm_fopen(filename,"rb")) != NULL) {
 		si = Sample_LoadFP(fp);
 		_mm_fclose(fp);
 	}
@@ -356,7 +353,7 @@ MIKMODAPI SAMPLE* Sample_Load(const CHAR* filename)
 MIKMODAPI void Sample_Free(SAMPLE* si)
 {
 	if(si) {
-		if (si->onfree != NULL) { si->onfree(si->ctx); }
+		if (si->onfree) si->onfree(si->ctx);
 		MD_SampleUnload(si->handle);
 		MikMod_free(si);
 	}
@@ -372,8 +369,10 @@ void Sample_Free_internal(SAMPLE *si)
 static void extract_channel(const char *src, char *dst, int num_chan, int num_samples, int samp_size, int channel)
 {
 	int i;
-	printf("Extract channel: %p %p, num_chan=%d, num_samples=%d, samp_size=%d, channel=%d\n",
-			src,dst,num_chan,num_samples,samp_size,channel);
+#ifdef MIKMOD_DEBUG
+	fprintf(stderr,"Extract channel: %p %p, num_chan=%d, num_samples=%d, samp_size=%d, channel=%d\n",
+		src,dst,num_chan,num_samples,samp_size,channel);
+#endif
 	src += channel * samp_size;
 
 	while (num_samples--)
@@ -386,4 +385,4 @@ static void extract_channel(const char *src, char *dst, int num_chan, int num_sa
 	}
 }
 
-/* ex:set ts=4: */
+/* ex:set ts=8: */
